Fix typos.

Test: art/test/testrunner/testrunner.py
Change-Id: I5f5e052c940650a3adb3a8717b84260e6b306500
diff --git a/compiler/jni/jni_compiler_test.cc b/compiler/jni/jni_compiler_test.cc
index f34e9b8..dc66234 100644
--- a/compiler/jni/jni_compiler_test.cc
+++ b/compiler/jni/jni_compiler_test.cc
@@ -76,7 +76,7 @@
   return gCurrentJni == static_cast<uint32_t>(JniKind::kNormal);
 }
 
-// Signifify that a different kind of JNI is about to be tested.
+// Signify that a different kind of JNI is about to be tested.
 static void UpdateCurrentJni(JniKind kind) {
   gCurrentJni = static_cast<uint32_t>(kind);
 }
diff --git a/openjdkjvmti/deopt_manager.cc b/openjdkjvmti/deopt_manager.cc
index 9e11a25..9f5db7e 100644
--- a/openjdkjvmti/deopt_manager.cc
+++ b/openjdkjvmti/deopt_manager.cc
@@ -277,7 +277,7 @@
 }
 
 void DeoptManager::RemoveDeoptimizeAllMethodsLocked(art::Thread* self) {
-  DCHECK_GT(global_deopt_count_, 0u) << "Request to remove non-existant global deoptimization!";
+  DCHECK_GT(global_deopt_count_, 0u) << "Request to remove non-existent global deoptimization!";
   global_deopt_count_--;
   if (global_deopt_count_ == 0) {
     PerformGlobalUndeoptimization(self);
diff --git a/runtime/base/bit_vector.cc b/runtime/base/bit_vector.cc
index 5e97a63..c706c7e 100644
--- a/runtime/base/bit_vector.cc
+++ b/runtime/base/bit_vector.cc
@@ -223,7 +223,7 @@
   // Difference until max, we know both accept it:
   //   There is no need to do more:
   //     If we are bigger than src, the upper bits are unchanged.
-  //     If we are smaller than src, the non-existant upper bits are 0 and thus can't get subtracted.
+  //     If we are smaller than src, the nonexistent upper bits are 0 and thus can't get subtracted.
   for (uint32_t idx = 0; idx < min_size; idx++) {
     storage_[idx] &= (~(src->GetRawStorageWord(idx)));
   }
diff --git a/runtime/gc/accounting/atomic_stack.h b/runtime/gc/accounting/atomic_stack.h
index 72eb827..f8d8271 100644
--- a/runtime/gc/accounting/atomic_stack.h
+++ b/runtime/gc/accounting/atomic_stack.h
@@ -41,7 +41,7 @@
 namespace gc {
 namespace accounting {
 
-// Internal representation is StackReference<T>, so this only works with mirror::Object or it's
+// Internal representation is StackReference<T>, so this only works with mirror::Object or its
 // subclasses.
 template <typename T>
 class AtomicStack {
diff --git a/runtime/gc/collector/concurrent_copying.cc b/runtime/gc/collector/concurrent_copying.cc
index f6e74da..e925d42 100644
--- a/runtime/gc/collector/concurrent_copying.cc
+++ b/runtime/gc/collector/concurrent_copying.cc
@@ -2027,7 +2027,7 @@
 void ConcurrentCopying::AssertToSpaceInvariantInNonMovingSpace(mirror::Object* obj,
                                                                mirror::Object* ref) {
   CHECK(!region_space_->HasAddress(ref)) << "obj=" << obj << " ref=" << ref;
-  // In a non-moving spaces. Check that the ref is marked.
+  // In a non-moving space. Check that the ref is marked.
   if (immune_spaces_.ContainsObject(ref)) {
     if (kUseBakerReadBarrier) {
       // Immune object may not be gray if called from the GC.
diff --git a/runtime/gc/collector/mark_sweep.cc b/runtime/gc/collector/mark_sweep.cc
index fdfe949..74ee2d1 100644
--- a/runtime/gc/collector/mark_sweep.cc
+++ b/runtime/gc/collector/mark_sweep.cc
@@ -1287,7 +1287,7 @@
   CHECK_GE(live_stack_freeze_size_, GetHeap()->GetLiveStack()->Size());
   {
     TimingLogger::ScopedTiming t2("MarkAllocStackAsLive", GetTimings());
-    // Mark everything allocated since the last as GC live so that we can sweep concurrently,
+    // Mark everything allocated since the last GC as live so that we can sweep concurrently,
     // knowing that new allocations won't be marked as live.
     accounting::ObjectStack* live_stack = heap_->GetLiveStack();
     heap_->MarkAllocStackAsLive(live_stack);
diff --git a/runtime/gc/collector/sticky_mark_sweep.cc b/runtime/gc/collector/sticky_mark_sweep.cc
index b66095f..d93bd89 100644
--- a/runtime/gc/collector/sticky_mark_sweep.cc
+++ b/runtime/gc/collector/sticky_mark_sweep.cc
@@ -63,7 +63,7 @@
 void StickyMarkSweep::MarkConcurrentRoots(VisitRootFlags flags) {
   TimingLogger::ScopedTiming t(__FUNCTION__, GetTimings());
   // Visit all runtime roots and clear dirty flags including class loader. This is done to prevent
-  // incorrect class unloading since the GC does not card mark when storing store the class during
+  // incorrect class unloading since the GC does not card mark when storing the class during
   // object allocation. Doing this for each allocation would be slow.
   // Since the card is not dirty, it means the object may not get scanned. This can cause class
   // unloading to occur even though the class and class loader are reachable through the object's
diff --git a/runtime/gc/heap.cc b/runtime/gc/heap.cc
index 84671c3..f22d025 100644
--- a/runtime/gc/heap.cc
+++ b/runtime/gc/heap.cc
@@ -1536,7 +1536,7 @@
 
 void Heap::RecordFreeRevoke() {
   // Subtract num_bytes_freed_revoke_ from num_bytes_allocated_ to cancel out the
-  // the ahead-of-time, bulk counting of bytes allocated in rosalloc thread-local buffers.
+  // ahead-of-time, bulk counting of bytes allocated in rosalloc thread-local buffers.
   // If there's a concurrent revoke, ok to not necessarily reset num_bytes_freed_revoke_
   // all the way to zero exactly as the remainder will be subtracted at the next GC.
   size_t bytes_freed = num_bytes_freed_revoke_.LoadSequentiallyConsistent();
@@ -1758,7 +1758,7 @@
 size_t Heap::GetObjectsAllocated() const {
   Thread* const self = Thread::Current();
   ScopedThreadStateChange tsc(self, kWaitingForGetObjectsAllocated);
-  // Prevent GC running during GetObjectsALlocated since we may get a checkpoint request that tells
+  // Prevent GC running during GetObjectsAllocated since we may get a checkpoint request that tells
   // us to suspend while we are doing SuspendAll. b/35232978
   gc::ScopedGCCriticalSection gcs(Thread::Current(),
                                   gc::kGcCauseGetObjectsAllocated,
diff --git a/runtime/gc/heap.h b/runtime/gc/heap.h
index faa6195..9f84d6d 100644
--- a/runtime/gc/heap.h
+++ b/runtime/gc/heap.h
@@ -551,7 +551,7 @@
     return total_memory - std::min(total_memory, byte_allocated);
   }
 
-  // get the space that corresponds to an object's address. Current implementation searches all
+  // Get the space that corresponds to an object's address. Current implementation searches all
   // spaces in turn. If fail_ok is false then failing to find a space will cause an abort.
   // TODO: consider using faster data structure like binary tree.
   space::ContinuousSpace* FindContinuousSpaceFromObject(ObjPtr<mirror::Object>, bool fail_ok) const
@@ -1312,7 +1312,7 @@
   AllocatorType current_allocator_;
   const AllocatorType current_non_moving_allocator_;
 
-  // Which GCs we run in order when we an allocation fails.
+  // Which GCs we run in order when an allocation fails.
   std::vector<collector::GcType> gc_plan_;
 
   // Bump pointer spaces.
diff --git a/runtime/gc/space/region_space.h b/runtime/gc/space/region_space.h
index 0e51f37..b4970ed 100644
--- a/runtime/gc/space/region_space.h
+++ b/runtime/gc/space/region_space.h
@@ -60,7 +60,7 @@
                                                 size_t* usable_size,
                                                 size_t* bytes_tl_bulk_allocated)
       REQUIRES(!region_lock_);
-  // Allocate/free large objects (objects that are larger than the region size.)
+  // Allocate/free large objects (objects that are larger than the region size).
   template<bool kForEvac>
   mirror::Object* AllocLarge(size_t num_bytes, size_t* bytes_allocated, size_t* usable_size,
                              size_t* bytes_tl_bulk_allocated) REQUIRES(!region_lock_);
diff --git a/runtime/gc/space/zygote_space.h b/runtime/gc/space/zygote_space.h
index 4d10de8..0823101 100644
--- a/runtime/gc/space/zygote_space.h
+++ b/runtime/gc/space/zygote_space.h
@@ -26,7 +26,7 @@
 
 namespace space {
 
-// An zygote space is a space which you cannot allocate into or free from.
+// A zygote space is a space which you cannot allocate into or free from.
 class ZygoteSpace FINAL : public ContinuousMemMapAllocSpace {
  public:
   // Returns the remaining storage in the out_map field.
diff --git a/runtime/runtime.h b/runtime/runtime.h
index 7ab9be5..c7f650e 100644
--- a/runtime/runtime.h
+++ b/runtime/runtime.h
@@ -325,7 +325,7 @@
   // instead.
   void VisitImageRoots(RootVisitor* visitor) REQUIRES_SHARED(Locks::mutator_lock_);
 
-  // Visit all of the roots we can do safely do concurrently.
+  // Visit all of the roots we can safely visit concurrently.
   void VisitConcurrentRoots(RootVisitor* visitor,
                             VisitRootFlags flags = kVisitRootFlagAllRoots)
       REQUIRES(!Locks::classlinker_classes_lock_, !Locks::trace_lock_)
diff --git a/runtime/verifier/reg_type_cache.cc b/runtime/verifier/reg_type_cache.cc
index 5564684..30aefed 100644
--- a/runtime/verifier/reg_type_cache.cc
+++ b/runtime/verifier/reg_type_cache.cc
@@ -278,7 +278,7 @@
       klass_entries_(allocator.Adapter(kArenaAllocVerifier)),
       can_load_classes_(can_load_classes),
       allocator_(allocator) {
-  DCHECK(can_suspend || !can_load_classes) << "Cannot load classes is suspension is disabled!";
+  DCHECK(can_suspend || !can_load_classes) << "Cannot load classes if suspension is disabled!";
   if (kIsDebugBuild && can_suspend) {
     Thread::Current()->AssertThreadSuspensionIsAllowable(gAborting == 0);
   }
diff --git a/test/075-verification-error/src/Main.java b/test/075-verification-error/src/Main.java
index 13aeaee..2519de5 100644
--- a/test/075-verification-error/src/Main.java
+++ b/test/075-verification-error/src/Main.java
@@ -31,7 +31,7 @@
         testBadInterfaceMethod();
      }
     /**
-     * Try to create and invoke a non-existant interface method.
+     * Try to create and invoke a non-existent interface method.
      */
     static void testBadInterfaceMethod() {
         BadInterface badiface = new BadIfaceImpl();
diff --git a/test/800-smali/smali/b_22045582.smali b/test/800-smali/smali/b_22045582.smali
index 3cb661a..09ea784 100644
--- a/test/800-smali/smali/b_22045582.smali
+++ b/test/800-smali/smali/b_22045582.smali
@@ -5,7 +5,7 @@
 
 .super Ljava/lang/Object;
 
-.method public static run()La/b/c/d/e/nonexistant;
+.method public static run()La/b/c/d/e/nonexistent;
     .registers 4
     # v1 is undefined, and the return type cannot be resolved. The Undefined should take
     # precedence here.
diff --git a/test/965-default-verify/src/Iface.java b/test/965-default-verify/src/Iface.java
index 180fba2..698230a 100644
--- a/test/965-default-verify/src/Iface.java
+++ b/test/965-default-verify/src/Iface.java
@@ -18,6 +18,6 @@
     return "Hello";
   }
   public default void verificationSoftFail() {
-    Statics.nonexistantFunction();
+    Statics.nonexistentFunction();
   }
 }
diff --git a/test/965-default-verify/src/Statics.java b/test/965-default-verify/src/Statics.java
index 2e17ba4..23a4a01 100644
--- a/test/965-default-verify/src/Statics.java
+++ b/test/965-default-verify/src/Statics.java
@@ -15,8 +15,7 @@
  */
 
 class Statics {
-  public static void nonexistantFunction() {
+  public static void nonexistentFunction() {
     System.out.println("I don't exist");
   }
 }
-
diff --git a/test/965-default-verify/src2/Statics.java b/test/965-default-verify/src2/Statics.java
index 7899ca9..73c5ec6 100644
--- a/test/965-default-verify/src2/Statics.java
+++ b/test/965-default-verify/src2/Statics.java
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 class Statics {
-  // public static void nonexistantFunction() {
+  // public static void nonexistentFunction() {
   //     System.out.println("I don't exist");
   // }
 }
diff --git a/test/etc/run-test-jar b/test/etc/run-test-jar
index 0243870..055cffb 100755
--- a/test/etc/run-test-jar
+++ b/test/etc/run-test-jar
@@ -570,7 +570,7 @@
     if [ "${RELOCATE}" = "y" ] ; then
       DALVIKVM_BOOT_OPT="-Ximage:${BOOT_IMAGE}"
     else
-      DALVIKVM_BOOT_OPT="-Ximage:/system/non-existant/core.art"
+      DALVIKVM_BOOT_OPT="-Ximage:/system/non-existent/core.art"
     fi
 else
     DALVIKVM_BOOT_OPT="-Ximage:${BOOT_IMAGE}"
diff --git a/test/046-reflect/src/Main.java b/test/046-reflect/src/Main.java
index b8a48ea..6d6cc13 100644
--- a/test/046-reflect/src/Main.java
+++ b/test/046-reflect/src/Main.java
@@ -232,10 +232,10 @@
             field.set(instance, null);
 
             /*
              * Try getDeclaredField on a non-existant field.
              */
             try {
-                field = target.getDeclaredField("nonExistant");
+                field = target.getDeclaredField("nonExistent");
                 System.out.println("ERROR: Expected NoSuchFieldException");
             } catch (NoSuchFieldException nsfe) {
                 String msg = nsfe.getMessage();
@@ -232,10 +232,10 @@
 
             /*
-             * Try getDeclaredField on a non-existant field.
+             * Try getDeclaredField on a non-existent field.
              */
             try {